@@ -24,7 +24,7 @@
 # import PyQt4 
 from PyQt4 import QtCore, QtGui
 import sys
-
+import osso
 # To allow os.popen ('<<Terminal command>>').read() commands
 import os
 
@@ -40,6 +40,8 @@ import gobject
 import gn_cellinfo
 #import gtk
 
+osso_c = osso.Context("healthcheck", "666", True)
+
 #Threading imports!
 # from threading import Thread
 # import time
